==> mumerge-0.0.5.tar.gz: mumerge-0.0.5/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 6)
if sys.version_info < min_version:
    error = """
mumerge does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(*(sys.version_info[:2] + min_version))
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'requirements.txt')) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines()
                    if not line.startswith('#')]


setup(
    name='mumerge',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="A tool for combining bed regions from multiple bed files in a probabilistically prinipled manner.",
    long_description=readme,
    long_description_content_type='text/x-rst',
    author="Jacob T. Stanley",
    author_email='jacob.stanley@colorado.edu',
    url='https://github.com/jtstanley/mumerge',
    python_requires='>={}'.format('.'.join(str(n) for n in min_version)),
    packages=find_packages(exclude=['docs', 'tests']),
    entry_points={
        'console_scripts': [
            'mumerge = mumerge.mumerge:main'
            # 'command = some.module:some_function',
        ],
    },
    include_package_data=True,
    package_data={
        'mumerge': ['mumerge/bin/bedtools', 
            # When adding files here, remember to update MANIFEST.in as well,
            # or else they will not be included in the distribution on PyPI!
            # 'path/to/data_file',
        ]
    },
    install_requires=requirements,
    license="BSD (3-clause)",
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
    ],
)

==> mumerge-1.1.0.tar.gz: mumerge-1.1.0/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 6)
if sys.version_info < min_version:
    error = """
mumerge does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(*(sys.version_info[:2] + min_version))
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open(path.join(here, 'requirements.txt')) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines()
                    if not line.startswith('#')]


setup(
    name='mumerge',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="A tool for combining bed regions from multiple bed files in a probabilistically prinipled manner.",
    long_description=readme,
    long_description_content_type='text/x-rst',
    author="Jacob T. Stanley",
    author_email='jacob.stanley@colorado.edu',
    url='https://github.com/Dowell-Lab/mumerge',
    python_requires='>={}'.format('.'.join(str(n) for n in min_version)),
    packages=find_packages(exclude=['docs', 'tests']),
    entry_points={
        'console_scripts': [
            'mumerge = mumerge.mumerge:main'
            # 'command = some.module:some_function',
        ],
    },
    include_package_data=True,
    package_data={
        'mumerge': ['mumerge/bin/bedtools', 
            # When adding files here, remember to update MANIFEST.in as well,
            # or else they will not be included in the distribution on PyPI!
            # 'path/to/data_file',
        ]
    },
    install_requires=requirements,
    license="GPL v3.0",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
    ],
)
